@@ -6,18 +6,18 @@ from os import path, makedirs
 # declared properly somewhere/somehow
 confdir = path.abspath(path.dirname(__file__))
 # use parent dir as dbdir else fallback to current dir
-dbdir = path.abspath(path.join(confdir, '../..')) if confdir.endswith('conf') \
-    else confdir
+dbdir = (
+    path.abspath(path.join(confdir, "../..")) if confdir.endswith("conf") else confdir
+)
 
 
 class BaseConfiguration(object):
     # Make this random (used to generate session keys)
-    SECRET_KEY = '74d9e9f9cd40e66fc6c4c2e9987dce48df3ce98542529fd0'
-    SQLALCHEMY_DATABASE_URI = 'sqlite:///{0}'.format(path.join(
-        dbdir, 'odcs.db'))
+    SECRET_KEY = "74d9e9f9cd40e66fc6c4c2e9987dce48df3ce98542529fd0"
+    SQLALCHEMY_DATABASE_URI = "sqlite:///{0}".format(path.join(dbdir, "odcs.db"))
     SQLALCHEMY_TRACK_MODIFICATIONS = False
 
-    HOST = '127.0.0.1'
+    HOST = "127.0.0.1"
     PORT = 5005
 
     DEBUG = False
@@ -26,13 +26,13 @@ class BaseConfiguration(object):
     NET_RETRY_INTERVAL = 30
 
     # Available backends are: console, file, journal.
-    LOG_BACKEND = 'journal'
+    LOG_BACKEND = "journal"
 
     # Path to log file when LOG_BACKEND is set to "file".
-    LOG_FILE = 'odcs.log'
+    LOG_FILE = "odcs.log"
 
     # Available log levels are: debug, info, warn, error.
-    LOG_LEVEL = 'info'
+    LOG_LEVEL = "info"
 
     SSL_ENABLED = False
 
@@ -60,37 +60,37 @@ class BaseConfiguration(object):
     #   }
     # }
     ALLOWED_CLIENTS = {
-        'groups': {},
-        'users': {},
+        "groups": {},
+        "users": {},
     }
 
     # Users in ADMINS are granted with admin permission.
     ADMINS = {
-        'groups': [],
-        'users': [],
+        "groups": [],
+        "users": [],
     }
 
     # OIDC base namespace
     # See also section pagure.io/odcs in
     # https://fedoraproject.org/wiki/Infrastructure/Authentication
-    OIDC_BASE_NAMESPACE = 'https://pagure.io/odcs/'
+    OIDC_BASE_NAMESPACE = "https://pagure.io/odcs/"
 
     # Select which authentication backend to work with. There are 3 choices
     # noauth: no authentication is enabled. Useful for development particularly.
     # kerberos: Kerberos authentication is enabled.
     # openidc: OpenIDC authentication is enabled.
-    AUTH_BACKEND = ''
+    AUTH_BACKEND = ""
 
     # Used for Kerberos authentication and to query user's groups.
     # Format: ldap://hostname[:port]
     # For example: ldap://ldap.example.com/
-    AUTH_LDAP_SERVER = ''
+    AUTH_LDAP_SERVER = ""
 
     # Group base to query groups from LDAP server.
     # Generally, it would be, for example, ou=groups,dc=example,dc=com
-    AUTH_LDAP_GROUP_BASE = ''
+    AUTH_LDAP_GROUP_BASE = ""
 
-    AUTH_OPENIDC_USERINFO_URI = 'https://id.fedoraproject.org/openidc/UserInfo'
+    AUTH_OPENIDC_USERINFO_URI = "https://id.fedoraproject.org/openidc/UserInfo"
 
     # Scope requested from Fedora Infra for permission of submitting request to
     # run a new compose.
@@ -103,25 +103,25 @@ class BaseConfiguration(object):
     # https://pagure.io/odcs/renew-compose
     # https://pagure.io/odcs/delete-compose
     AUTH_OPENIDC_REQUIRED_SCOPES = [
-        'openid',
-        'https://id.fedoraproject.org/scope/groups',
+        "openid",
+        "https://id.fedoraproject.org/scope/groups",
     ]
 
     # Select backend where message will be sent to. Currently, umb is supported
     # which means the Unified Message Bus.
-    MESSAGING_BACKEND = ''  # fedora-messaging or umb
+    MESSAGING_BACKEND = ""  # fedora-messaging or umb
 
     # List of broker URLs. Each of them is a string consisting of domain and
     # optiona port.
     MESSAGING_BROKER_URLS = []
 
     # Path to certificate file used to authenticate ODCS by messaging broker.
-    MESSAGING_CERT_FILE = ''
+    MESSAGING_CERT_FILE = ""
 
     # Path to private key file used to authenticate ODCS by messaging broker.
-    MESSAGING_KEY_FILE = ''
+    MESSAGING_KEY_FILE = ""
 
-    MESSAGING_CA_CERT = ''
+    MESSAGING_CA_CERT = ""
 
     # The MESSAGING_TOPIC is used as topic for messages sent when compose
     # state is change.
@@ -130,8 +130,8 @@ class BaseConfiguration(object):
     # composes.
     # For umb, it is the ActiveMQ virtual topic e.g.
     # VirtualTopic.eng.odcs.state.changed.
-    MESSAGING_TOPIC = ''
-    INTERNAL_MESSAGING_TOPIC = ''
+    MESSAGING_TOPIC = ""
+    INTERNAL_MESSAGING_TOPIC = ""
 
     # Definitions of raw Pungi configs for "raw_config" source_type.
     # RAW_CONFIG_URLS = {
@@ -143,7 +143,7 @@ class BaseConfiguration(object):
     # }
 
     # Command line arguments used to construct pungi-koji command.
-    PUNGI_KOJI_ARGS = ['--nightly']
+    PUNGI_KOJI_ARGS = []
 
     # Command line argument for raw_config source type, which overwrite
     # arguments listed PUNGI_KOJI_ARGS.
@@ -160,8 +160,8 @@ class BaseConfiguration(object):
 
 class DevConfiguration(BaseConfiguration):
     DEBUG = True
-    LOG_BACKEND = 'console'
-    LOG_LEVEL = 'debug'
+    LOG_BACKEND = "console"
+    LOG_LEVEL = "debug"
 
     # Global network-related values, in seconds
     NET_TIMEOUT = 5
@@ -171,27 +171,29 @@ class DevConfiguration(BaseConfiguration):
         makedirs(TARGET_DIR, mode=0o775)
     except OSError as ex:
         if ex.errno != errno.EEXIST:
-            raise RuntimeError("Can't create compose target dir %s: %s" % (TARGET_DIR, ex.strerror))
+            raise RuntimeError(
+                "Can't create compose target dir %s: %s" % (TARGET_DIR, ex.strerror)
+            )
 
-    PUNGI_CONF_PATH = path.join(confdir, 'pungi.conf')
-    AUTH_BACKEND = 'noauth'
-    AUTH_OPENIDC_USERINFO_URI = 'https://iddev.fedorainfracloud.org/openidc/UserInfo'
+    PUNGI_CONF_PATH = path.join(confdir, "pungi.conf")
+    AUTH_BACKEND = "noauth"
+    AUTH_OPENIDC_USERINFO_URI = "https://iddev.fedorainfracloud.org/openidc/UserInfo"
 
-    KOJI_PROFILE = 'stg'
+    KOJI_PROFILE = "stg"
 
-    RAW_CONFIG_WRAPPER_CONF_PATH = path.join(confdir, 'raw_config_wrapper.conf')
+    RAW_CONFIG_WRAPPER_CONF_PATH = path.join(confdir, "raw_config_wrapper.conf")
 
 
 class TestConfiguration(BaseConfiguration):
-    LOG_BACKEND = 'console'
-    LOG_LEVEL = 'debug'
+    LOG_BACKEND = "console"
+    LOG_LEVEL = "debug"
     DEBUG = True
 
     # Use in-memory sqlite db to make tests fast.
-    SQLALCHEMY_DATABASE_URI = 'sqlite://'
+    SQLALCHEMY_DATABASE_URI = "sqlite://"
 
-    PUNGI_CONF_PATH = path.join(confdir, 'pungi.conf')
-    RAW_CONFIG_WRAPPER_CONF_PATH = path.join(confdir, 'raw_config_wrapper.conf')
+    PUNGI_CONF_PATH = path.join(confdir, "pungi.conf")
+    RAW_CONFIG_WRAPPER_CONF_PATH = path.join(confdir, "raw_config_wrapper.conf")
     # Global network-related values, in seconds
     NET_TIMEOUT = 0
     NET_RETRY_INTERVAL = 0
@@ -200,14 +202,16 @@ class TestConfiguration(BaseConfiguration):
         makedirs(TARGET_DIR, mode=0o775)
     except OSError as ex:
         if ex.errno != errno.EEXIST:
-            raise RuntimeError("Can't create compose target dir %s: %s" % (TARGET_DIR, ex.strerror))
+            raise RuntimeError(
+                "Can't create compose target dir %s: %s" % (TARGET_DIR, ex.strerror)
+            )
 
-    AUTH_BACKEND = 'noauth'
-    AUTH_LDAP_SERVER = 'ldap://ldap.example.com'
-    AUTH_LDAP_GROUP_BASE = 'ou=groups,dc=example,dc=com'
+    AUTH_BACKEND = "noauth"
+    AUTH_LDAP_SERVER = "ldap://ldap.example.com"
+    AUTH_LDAP_GROUP_BASE = "ou=groups,dc=example,dc=com"
 
-    MESSAGING_BACKEND = 'rhmsg'
-    KOJI_PROFILE = 'koji'
+    MESSAGING_BACKEND = "rhmsg"
+    KOJI_PROFILE = "koji"
 
 
 class ProdConfiguration(BaseConfiguration):
