@@ -159,7 +159,7 @@ class RawPungiConfig(BasePungiConfig):
 
                 # Load the raw_config_wrapper and update pungi_config_dump.
                 raw_config_wrapper = PyConfigParser()
-                raw_config_wrapper.load_from_file(main_cfg_path)
+                raw_config_wrapper.load_from_file(os.path.join(topdir, "pungi.conf"))
                 pungi_config_dump.update(raw_config_wrapper)
 
             # Create the pungi.json
@@ -230,6 +230,7 @@ class PungiConfig(BasePungiConfig):
         module_defaults_url=None,
         scratch_modules=None,
         scratch_build_tasks=None,
+        modules=None,
     ):
         super(PungiConfig, self).__init__()
         self.release_name = release_name
@@ -248,6 +249,7 @@ class PungiConfig(BasePungiConfig):
         self.packages = packages or []
         self.builds = builds or []
         self.scratch_modules = scratch_modules.split(" ") if scratch_modules else []
+        self.modules = modules.split(" ") if modules else []
         self.scratch_build_tasks = (
             scratch_build_tasks.split(" ") if scratch_build_tasks else []
         )
@@ -507,6 +509,8 @@ class Pungi(object):
         if compose.parent_pungi_compose_ids:
             for compose_id in compose.parent_pungi_compose_ids.split(" "):
                 pungi_cmd.append("--parent-compose-id=%s" % str(compose_id))
+        if compose.respin_of:
+            pungi_cmd.append("--respin-of=%s" % str(compose.respin_of))
 
         if self.koji_event:
             pungi_cmd += ["--koji-event", str(self.koji_event)]
