@@ -138,6 +138,24 @@ class TestBackend(ModelsBaseTest):
         c = db.session.query(Compose).filter(Compose.id == 1).one()
         self.assertEqual(c.source, "")
 
+    @mock_mbs()
+    def test_resolve_compose_uses_older_module(self):
+        c = Compose.create(
+            db.session,
+            "me",
+            PungiSourceType.MODULE,
+            "leaf:master",
+            COMPOSE_RESULTS["repository"],
+            3600,
+        )
+        db.session.commit()
+
+        resolve_compose(c)
+        db.session.commit()
+
+        c = db.session.query(Compose).filter(Compose.id == 1).one()
+        self.assertEqual(c.source, "leaf:master:1:00000000 lib:master:1:abcdef")
+
     @mock_mbs()
     def test_resolve_compose_module_include_done_modules(self):
         c = Compose.create(
@@ -525,6 +543,44 @@ class TestBackend(ModelsBaseTest):
         reused_c = get_reusable_compose(c)
         self.assertEqual(reused_c, old_c)
 
+    @patch("odcs.server.backend.koji_get_inherited_tags")
+    @patch("odcs.server.backend.create_koji_session")
+    def test_get_reusable_tag_compose_in_generating(
+        self, create_koji_session, koji_get_inherited_tags
+    ):
+        koji_get_inherited_tags.return_value = ["foo", "bar"]
+        koji_session = MagicMock()
+        create_koji_session.return_value = koji_session
+        koji_session.tagChangedSinceEvent.return_value = False
+
+        old_c = Compose.create(
+            db.session,
+            "me",
+            PungiSourceType.KOJI_TAG,
+            "foo",
+            COMPOSE_RESULTS["repository"],
+            3600,
+            packages="ed",
+        )
+        old_c.koji_event = 1
+        old_c.state = COMPOSE_STATES["generating"]
+        c = Compose.create(
+            db.session,
+            "me",
+            PungiSourceType.KOJI_TAG,
+            "foo",
+            COMPOSE_RESULTS["repository"],
+            3600,
+            packages="ed",
+        )
+        c.koji_event = 2
+        db.session.add(old_c)
+        db.session.add(c)
+        db.session.commit()
+
+        reused_c = get_reusable_compose(c)
+        self.assertEqual(reused_c, old_c)
+
     @patch("odcs.server.backend.koji_get_inherited_tags")
     @patch("odcs.server.backend.create_koji_session")
     def test_get_reusable_tag_compose_none_koji_event(
@@ -1439,10 +1495,12 @@ class TestGeneratePungiCompose(ModelsBaseTest):
         # run asserts against it.
         self.pungi_config = None
         self.old_compose = None
+        self.pungi_koji_event = None
 
         def fake_pungi_run(pungi_cls, compose):
             self.pungi_config = pungi_cls.pungi_cfg
             self.old_compose = pungi_cls.old_compose
+            self.pungi_koji_event = pungi_cls.koji_event
 
         self.patch_pungi_run = patch("odcs.server.pungi.Pungi.run", autospec=True)
         self.pungi_run = self.patch_pungi_run.start()
@@ -1610,6 +1668,7 @@ class TestGeneratePungiCompose(ModelsBaseTest):
         c.compose_type = "production"
         c.pungi_compose_id = "compose-1-10-2020110.n.0"
         c.id = 1
+        c.koji_event = 123456
 
         fake_raw_config_urls = {
             "pungi_cfg": {
@@ -1620,6 +1679,7 @@ class TestGeneratePungiCompose(ModelsBaseTest):
         with patch.object(conf, "raw_config_urls", new=fake_raw_config_urls):
             generate_pungi_compose(c)
 
+        self.assertEqual(self.pungi_koji_event, c.koji_event)
         self.assertEqual(c.pungi_config_dump, "fake\npungi\nconf\n")
         self.assertEqual(
             self.pungi_config.pungi_cfg,
